summaryrefslogtreecommitdiffstats
path: root/chrome/common/service_messages.h
diff options
context:
space:
mode:
authorsanjeevr@chromium.org <sanjeevr@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-05-11 20:41:35 +0000
committersanjeevr@chromium.org <sanjeevr@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-05-11 20:41:35 +0000
commitde119cf2b1e0cc6b6ab2352812adb14726633413 (patch)
treea43fe7e052f03a0bd9c3a54c317c2a8a71f7df8d /chrome/common/service_messages.h
parente64648531fc7386c139dffadefa746996264b90f (diff)
downloadchromium_src-de119cf2b1e0cc6b6ab2352812adb14726633413.zip
chromium_src-de119cf2b1e0cc6b6ab2352812adb14726633413.tar.gz
chromium_src-de119cf2b1e0cc6b6ab2352812adb14726633413.tar.bz2
Changed the IPC between the browser and the service process to return more detailed information about the cloud print proxy. This is a first step towards the new login mechanism for Cloud Print.
BUG=None TEST=Unit-tests, enabling disabling cloud print proxy Review URL: http://codereview.chromium.org/7001012 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@85038 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/common/service_messages.h')
-rw-r--r--chrome/common/service_messages.h26
1 files changed, 14 insertions, 12 deletions
diff --git a/chrome/common/service_messages.h b/chrome/common/service_messages.h
index faf5b1a..c46c4af 100644
--- a/chrome/common/service_messages.h
+++ b/chrome/common/service_messages.h
@@ -5,11 +5,18 @@
// Multiply-included message file, no traditional include guard.
#include <string>
+#include "chrome/common/cloud_print/cloud_print_proxy_info.h"
#include "ipc/ipc_channel_handle.h"
#include "ipc/ipc_message_macros.h"
#define IPC_MESSAGE_START ServiceMsgStart
+IPC_STRUCT_TRAITS_BEGIN(cloud_print::CloudPrintProxyInfo)
+ IPC_STRUCT_TRAITS_MEMBER(enabled)
+ IPC_STRUCT_TRAITS_MEMBER(email)
+ IPC_STRUCT_TRAITS_MEMBER(proxy_id)
+IPC_STRUCT_TRAITS_END()
+
//-----------------------------------------------------------------------------
// Service process messages:
// These are messages from the browser to the service process.
@@ -17,17 +24,13 @@
// of the account to be used.
IPC_MESSAGE_CONTROL1(ServiceMsg_EnableCloudPrintProxy,
std::string /* lsid */)
-// Tell the service process to enable the cloud proxy passing in specific
-// tokens to be used.
-IPC_MESSAGE_CONTROL2(ServiceMsg_EnableCloudPrintProxyWithTokens,
- std::string, /* token for cloudprint service */
- std::string /* token for Google Talk service */)
+
// Tell the service process to disable the cloud proxy.
IPC_MESSAGE_CONTROL0(ServiceMsg_DisableCloudPrintProxy)
-// Requests a message back on whether the cloud print proxy is
-// enabled.
-IPC_MESSAGE_CONTROL0(ServiceMsg_IsCloudPrintProxyEnabled)
+// Requests a message back on the current status of the cloud print proxy
+// (whether it is enabled, the email address and the proxy id).
+IPC_MESSAGE_CONTROL0(ServiceMsg_GetCloudPrintProxyInfo)
// Tell the service process to shutdown.
IPC_MESSAGE_CONTROL0(ServiceMsg_Shutdown)
@@ -41,7 +44,6 @@ IPC_MESSAGE_CONTROL0(ServiceMsg_UpdateAvailable)
// Sent when the cloud print proxy has an authentication error.
IPC_MESSAGE_CONTROL0(ServiceHostMsg_CloudPrintProxy_AuthError)
-// Sent as a response to a request for enablement status.
-IPC_MESSAGE_CONTROL2(ServiceHostMsg_CloudPrintProxy_IsEnabled,
- bool, /* Is the proxy enabled? */
- std::string /* Email address of account */)
+// Sent as a response to a request for cloud print proxy info
+IPC_MESSAGE_CONTROL1(ServiceHostMsg_CloudPrintProxy_Info,
+ cloud_print::CloudPrintProxyInfo /* proxy info */)